This function facilitates a comparison to check if at least a specified
proportion or count of values in a logical vector evaluate to TRUE.
See also
Other basic_quantifiers:
at_most(),
exactly_equal(),
less_than(),
more_than()
Examples
# Check if at least 50% of values are TRUE
at_least(c(TRUE, TRUE, FALSE), p = 0.5) # Returns TRUE
#> [1] TRUE