This function facilitates a comparison to check if at most a specified
proportion or count of values in a logical vector evaluate to TRUE.
See also
Other basic_quantifiers:
at_least(),
exactly_equal(),
less_than(),
more_than()
Examples
# Check if at most 20% of values are TRUE
at_most(c(TRUE, FALSE, TRUE, TRUE), p = 0.2) # Returns TRUE
#> [1] FALSE