This function facilitates a comparison to check if the proportion or count of values in a logical vector is exactly equal to a specified value.
Value
TRUE if the proportion or count of values is exactly equal to
the specified value, otherwise FALSE.
See also
Other basic_quantifiers:
at_least(),
at_most(),
less_than(),
more_than()
Examples
# Check if all values are TRUE
exactly_equal(c(TRUE, TRUE, TRUE), p = 1.0) # Returns TRUE
#> [1] TRUE