powered by
This function facilitates a comparison to check if at least a specified proportion or count of values in a logical vector evaluate to TRUE.
TRUE
at_least(logical_vec, p = NULL, n = NULL, na.rm = FALSE)
TRUE if the condition is met for at least the specified proportion or count, otherwise FALSE.
FALSE
A logical vector.
Proportion value (0 to 1) to compare against.
Count value (integer) to compare against.
Logical. Should missing values be removed before calculation?
Other basic_quantifiers: at_most(), exactly_equal(), less_than(), more_than()
at_most()
exactly_equal()
less_than()
more_than()
# Check if at least 50% of values are TRUE at_least(c(TRUE, TRUE, FALSE), p = 0.5) # Returns TRUE
Run the code above in your browser using DataLab